==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/GridColumnOptionsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnOptionsBaseDescriptionMetadata, _super);
    function GridColumnOptionsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsBaseDescriptionMetadata.a == null) {
            GridColumnOptionsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsBaseDescriptionMetadata.c(GridColumnOptionsBaseDescriptionMetadata.a);
        }
        if (a.g(GridColumnOptionsBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnOptionsBaseDescriptionMetadata.a);
        ColumnDescriptionMetadata.d(a);
    };
    GridColumnOptionsBaseDescriptionMetadata.c = function (a) {
        a.item("AutoSize", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("ActualBaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("ActualBaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("ButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ButtonFontFamily", "(w:ButtonFontFamily/FontFamilyTransform,xam:ButtonFontFamily,wf:ButtonFontFamily,web:buttonTextStyle/FontFamilyTransform)String");
        a.item("ButtonFontSize", "(w:ButtonFontSize,xam:ButtonFontSize,wf:ButtonFontSize,web:buttonTextStyle/FontSizeTransform)Number:double");
        a.item("ButtonFontStyle", "(w:ButtonFontStyle/FontStyleTransform,xam:ButtonFontFamily/FontStyleTransform,wf:ButtonFontFamily/FontStyleTransform,web:buttonTextStyle/FontStyleTransform)String");
        a.item("ButtonFontWeight", "(w:ButtonFontWeight/FontWeightTransform,xam:ButtonFontFamily/FontWeightTransform,wf:ButtonFontFamily/FontWeightTransform,web:buttonTextStyle/FontWeightTransform)String");
        a.item("Column", "ExportedType:Column");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("LabelFontFamily", "(w:LabelFontFamily/FontFamilyTransform,xam:LabelFontFamily,wf:LabelFontFamily,web:labelTextStyle/FontFamilyTransform)String");
        a.item("LabelFontSize", "(w:LabelFontSize,xam:LabelFontSize,wf:LabelFontSize,web:labelTextStyle/FontSizeTransform)Number:double");
        a.item("LabelFontStyle", "(w:LabelFontStyle/FontStyleTransform,xam:LabelFontFamily/FontStyleTransform,wf:LabelFontFamily/FontStyleTransform,web:labelTextStyle/FontStyleTransform)String");
        a.item("LabelFontWeight", "(w:LabelFontWeight/FontWeightTransform,xam:LabelFontFamily/FontWeightTransform,wf:LabelFontFamily/FontWeightTransform,web:labelTextStyle/FontWeightTransform)String");
        a.item("TextColor", "Brush");
    };
    GridColumnOptionsBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.b(a);
        a.t("GridColumnOptionsBase", GridColumnOptionsBaseDescriptionMetadata.a);
    };
    GridColumnOptionsBaseDescriptionMetadata.$t = markType(GridColumnOptionsBaseDescriptionMetadata, 'GridColumnOptionsBaseDescriptionMetadata');
    GridColumnOptionsBaseDescriptionMetadata.a = null;
    return GridColumnOptionsBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridColumnOptionsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnOptionsBaseDescriptionMetadata, _super);
    function GridColumnOptionsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsBaseDescriptionMetadata.a == null) {
            GridColumnOptionsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsBaseDescriptionMetadata.c(GridColumnOptionsBaseDescriptionMetadata.a);
        }
        if (a.j(GridColumnOptionsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnOptionsBaseDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridColumnOptionsBaseDescriptionMetadata.c = function (a) {
        a.item("AutoSize", "Boolean");
        a.item("BackgroundColor", "Brush");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("ActualBaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("ActualBaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("ButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualButtonDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualButtonDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ButtonFontFamily", "(w:ButtonFontFamily/FontFamilyTransform,xam:ButtonFontFamily,wf:ButtonFontFamily,web:buttonTextStyle/FontFamilyTransform)String");
        a.item("ButtonFontSize", "(w:ButtonFontSize,xam:ButtonFontSize,wf:ButtonFontSize,web:buttonTextStyle/FontSizeTransform)Number:double");
        a.item("ButtonFontStyle", "(w:ButtonFontStyle/FontStyleTransform,xam:ButtonFontFamily/FontStyleTransform,wf:ButtonFontFamily/FontStyleTransform,web:buttonTextStyle/FontStyleTransform)String");
        a.item("ButtonFontWeight", "(w:ButtonFontWeight/FontWeightTransform,xam:ButtonFontFamily/FontWeightTransform,wf:ButtonFontFamily/FontWeightTransform,web:buttonTextStyle/FontWeightTransform)String");
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("LabelFontFamily", "(w:LabelFontFamily/FontFamilyTransform,xam:LabelFontFamily,wf:LabelFontFamily,web:labelTextStyle/FontFamilyTransform)String");
        a.item("LabelFontSize", "(w:LabelFontSize,xam:LabelFontSize,wf:LabelFontSize,web:labelTextStyle/FontSizeTransform)Number:double");
        a.item("LabelFontStyle", "(w:LabelFontStyle/FontStyleTransform,xam:LabelFontFamily/FontStyleTransform,wf:LabelFontFamily/FontStyleTransform,web:labelTextStyle/FontStyleTransform)String");
        a.item("LabelFontWeight", "(w:LabelFontWeight/FontWeightTransform,xam:LabelFontFamily/FontWeightTransform,wf:LabelFontFamily/FontWeightTransform,web:labelTextStyle/FontWeightTransform)String");
        a.item("TextColor", "Brush");
    };
    GridColumnOptionsBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.b(a);
        a.z("GridColumnOptionsBase", GridColumnOptionsBaseDescriptionMetadata.a);
    };
    GridColumnOptionsBaseDescriptionMetadata.$t = markType(GridColumnOptionsBaseDescriptionMetadata, 'GridColumnOptionsBaseDescriptionMetadata');
    GridColumnOptionsBaseDescriptionMetadata.a = null;
    return GridColumnOptionsBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsBaseDescriptionMetadata };
